### R code from vignette source 'CDVine-package.rnw'

###################################################
### code chunk number 1: options
###################################################
options(prompt = "R> ", continue = "+  ", width = 80, digits=4, useFancyQuotes = FALSE)


###################################################
### code chunk number 2: library
###################################################
library("CDVine")


###################################################
### code chunk number 3: seed
###################################################
set.seed(10)


###################################################
### code chunk number 4: BiCopCDFPDF
###################################################
u1 = seq(0.02,0.98,by=0.02)
u2 = seq(0.02,0.98,by=0.02)
copCDF = matrix(0,49,49)
copPDF = matrix(0,49,49)
for(i in 1:49) for(j in 1:49) copCDF[i,j] = BiCopCDF(u1=u1[i],u2=u2[j],family=2,par=0.7,par2=4)
for(i in 1:49) for(j in 1:49) copPDF[i,j] = BiCopPDF(u1=u1[i],u2=u2[j],family=2,par=0.7,par2=4)


###################################################
### code chunk number 5: BiCopCDFPDFPlot
###################################################
par(mfrow=c(1,2),cex.axis=0.7,cex.lab=0.9)
persp(u1,u2,copCDF,theta=-25,main="Copula CDF",ticktype="detailed",zlab="",nticks=9)
persp(u1,u2,copPDF,theta=-25,main="Copula PDF",ticktype="detailed",zlab="",nticks=9)


###################################################
### code chunk number 6: BiCopHfunc
###################################################
BiCopHfunc(u1=0.7, u2=0.4, family=5, par=6)


###################################################
### code chunk number 7: BiCopPar2Tau
###################################################
tau1=BiCopPar2Tau(family=1,par=0.7)
BiCopTau2Par(family=1,tau=tau1)


###################################################
### code chunk number 8: BiCopPar2TailDep
###################################################
BiCopPar2TailDep(family=7,par=0.8,par2=1.5)


###################################################
### code chunk number 9: BiCopSim-seed
###################################################
set.seed(10)


###################################################
### code chunk number 10: BiCopSim
###################################################
dat0 = BiCopSim(N=500,family=3,par=BiCopTau2Par(family=3,tau=0.5))
dat90 = BiCopSim(N=500,family=23,par=BiCopTau2Par(family=23,tau=-0.5))
dat180 = BiCopSim(N=500,family=13,par=BiCopTau2Par(family=13,tau=0.5))
dat270 = BiCopSim(N=500,family=33,par=BiCopTau2Par(family=33,tau=-0.5))


###################################################
### code chunk number 11: BiCopSimPlot
###################################################
par(mfrow=c(1,4),cex.main=3,cex.lab=2,cex.axis=2)
plot(dat0, main="0 degrees", xlab="u1", ylab="u2")
plot(dat90, main="90 degrees", xlab="u1", ylab="u2")
plot(dat180, main="180 degrees", xlab="u1", ylab="u2")
plot(dat270, main="270 degrees", xlab="u1", ylab="u2")


###################################################
### code chunk number 12: BiCopMetaContour-seed
###################################################
set.seed(10)


###################################################
### code chunk number 13: BiCopMetaContour (eval = FALSE)
###################################################
## par(mfrow=c(1,3),cex.main=2,cex.lab=1.5,cex.axis=1.5)
## dat = BiCopSim(N=1000,family=4,par=2)
## BiCopMetaContour(u1=dat[,1],u2=dat[,2],bw=2,size=100,levels=c(0.01,0.05,0.1,0.15,0.2),par=0,family="emp",main="Empirical with N=1000")
## BiCopMetaContour(u1=NULL,u2=NULL,bw=1,size=100,levels=c(0.01,0.05,0.1,0.15,0.2),family=4,par=2,main="Standard normal margins")
## BiCopMetaContour(u1=NULL,u2=NULL,bw=1,size=100,family=4,par=2,margins="gamma",margins.par=c(1.5,0.75),levels = c(0.005,0.01,0.03,0.05,0.07,0.09),main="Gamma margins")           


###################################################
### code chunk number 14: plotBiCopMetaContour
###################################################
par(mfrow=c(1,3),cex.main=2,cex.lab=1.5,cex.axis=1.5)
dat = BiCopSim(N=1000,family=4,par=2)
BiCopMetaContour(u1=dat[,1],u2=dat[,2],bw=2,size=100,levels=c(0.01,0.05,0.1,0.15,0.2),par=0,family="emp",main="Empirical with N=1000")
BiCopMetaContour(u1=NULL,u2=NULL,bw=1,size=100,levels=c(0.01,0.05,0.1,0.15,0.2),family=4,par=2,main="Standard normal margins")
BiCopMetaContour(u1=NULL,u2=NULL,bw=1,size=100,family=4,par=2,margins="gamma",margins.par=c(1.5,0.75),levels = c(0.005,0.01,0.03,0.05,0.07,0.09),main="Gamma margins")           


###################################################
### code chunk number 15: BiCopLambda-seed
###################################################
set.seed(10)


###################################################
### code chunk number 16: BiCopLambda (eval = FALSE)
###################################################
## dat = BiCopSim(N=1000,family=6,par=2)
## par(mfrow=c(1,3),cex.main=2,cex.lab=1.5,cex.axis=1.5)
## BiCopLambda(u1=dat[,1],u2=dat[,2])
## BiCopLambda(family=6,par=2)
## BiCopLambda(u1=dat[,1],u2=dat[,2],family=6,par=2)         


###################################################
### code chunk number 17: plotBiCopLambda
###################################################
dat = BiCopSim(N=1000,family=6,par=2)
par(mfrow=c(1,3),cex.main=2,cex.lab=1.5,cex.axis=1.5)
BiCopLambda(u1=dat[,1],u2=dat[,2])
BiCopLambda(family=6,par=2)
BiCopLambda(u1=dat[,1],u2=dat[,2],family=6,par=2)         


###################################################
### code chunk number 18: BiCopGofKendall
###################################################
gof = BiCopGofKendall(u1=dat[,1],u2=dat[,2],family=5)
gof$p.value.CvM 
gof$p.value.KS


###################################################
### code chunk number 19: BiCopVuongClarke (eval = FALSE)
###################################################
## BiCopVuongClarke(u1, u2, familyset, correction, level)


###################################################
### code chunk number 20: BiCopSelect
###################################################
cop1 = BiCopSelect(u1=dat[,1],u2=dat[,2],familyset=NA,indeptest=TRUE,level=0.05)
cop1$family
cop1$par


###################################################
### code chunk number 21: BiCopEst-seed
###################################################
set.seed(10)


###################################################
### code chunk number 22: BiCopEst
###################################################
dat = BiCopSim(N=1000,family=1,par=0.7)
BiCopEst(u1=dat[,1], u2=dat[,2], family=1, method="mle", se=TRUE)
BiCopEst(u1=dat[,1], u2=dat[,2], family=2, method="mle", se=TRUE, max.df=30)


###################################################
### code chunk number 23: CVineExample
###################################################
type = 1
family = c(1,3,6,2,1,5)
par = c(0.5,1.3,2.1,-0.3,0.2,1.7)
par2 = c(0,0,0,3,0,0)


###################################################
### code chunk number 24: CDVinePar2Tau
###################################################
CDVinePar2Tau(family=family,par=par,par2=par2)


###################################################
### code chunk number 25: CDVineSim-seed
###################################################
set.seed(10)


###################################################
### code chunk number 26: CVineSim
###################################################
dat = CDVineSim(N=500, family=family, par=par, par2=par2, type=type)
head(dat)


###################################################
### code chunk number 27: CVineCopSelect (eval = FALSE)
###################################################
## CDVineCopSelect(data, familyset, type, selectioncrit, indeptest, level)


###################################################
### code chunk number 28: CDVineSeqEst (eval = FALSE)
###################################################
## CDVineSeqEst(data, family, type, method, se, max.df, max.BB)


###################################################
### code chunk number 29: CDVineLogLik (eval = FALSE)
###################################################
## CDVineLogLik(data, family, par, par2, type)


###################################################
### code chunk number 30: CDVineMLE (eval = FALSE)
###################################################
## CDVineMLE(data, family, start, start2, type, maxit, max.df, max.BB)


###################################################
### code chunk number 31: CDVineVuongTest (eval = FALSE)
###################################################
## CDVineVuongTest(data, Model1.order, Model2.order, Model1.family, Model2.family, Model1.par, Model2.par, Model1.par2, Model2.par2, Model1.type, Model2.type)


###################################################
### code chunk number 32: CDVineTreePlot (eval = FALSE)
###################################################
## CDVineTreePlot(data, family, par, par2, names, type, method, max.df, max.BB, tree, edge.labels, P)


###################################################
### code chunk number 33: data
###################################################
data(worldindices)


###################################################
### code chunk number 34: EDA_pairs (eval = FALSE)
###################################################
## panel.contour <- function(x, y, bw=2, size=100)
## {
##     usr <- par("usr")
##     on.exit(par(usr))
##     par(usr = c(-3,3,-3,3), new=TRUE)
## 
##     BiCopMetaContour(x, y, bw, size, axes=FALSE)
## }
## 
## pairs(worldindices, lower.panel=panel.contour, gap=0) 


###################################################
### code chunk number 35: EDA_pairs_plot
###################################################
panel.contour <- function(x, y, bw=2, size=100)
{
    usr <- par("usr")
    on.exit(par(usr))
    par(usr = c(-3,3,-3,3), new=TRUE)

    BiCopMetaContour(x, y, bw, size, axes=FALSE)
}

pairs(worldindices, lower.panel=panel.contour, gap=0) 


###################################################
### code chunk number 36: EDA_graphical (eval = FALSE)
###################################################
## par(mfrow=c(1,3),cex.main=2,cex.lab=1.5,cex.axis=1.5)
## BiCopKPlot(worldindices[,5],worldindices[,6],main="K-plot")
## BiCopChiPlot(worldindices[,5],worldindices[,6],xlim=c(-1,1),ylim=c(-1,1),main="Chi-plot")
## param=BiCopEst(worldindices[,5],worldindices[,6],2)
## BiCopLambda(worldindices[,5],worldindices[,6],family=2,par=param$par,par2=param$par2,main="Lambda-function")


###################################################
### code chunk number 37: EDA_graphical_plot
###################################################
par(mfrow=c(1,3),cex.main=2,cex.lab=1.5,cex.axis=1.5)
BiCopKPlot(worldindices[,5],worldindices[,6],main="K-plot")
BiCopChiPlot(worldindices[,5],worldindices[,6],xlim=c(-1,1),ylim=c(-1,1),main="Chi-plot")
param=BiCopEst(worldindices[,5],worldindices[,6],2)
BiCopLambda(worldindices[,5],worldindices[,6],family=2,par=param$par,par2=param$par2,main="Lambda-function")


###################################################
### code chunk number 38: EDA_analytical1
###################################################
BiCopIndTest(worldindices[,5],worldindices[,6])$p.value


###################################################
### code chunk number 39: EDA_analytical2
###################################################
BiCopVuongClarke(worldindices[,5],worldindices[,6],familyset=c(1:10,13,14,16:20))
BiCopSelect(worldindices[,5],worldindices[,6],familyset=c(1:10,13,14,16:20))$family


###################################################
### code chunk number 40: cvine
###################################################
order = c(5, 2, 6, 4, 3, 1) 
dat=worldindices[,order]
family=c(9,  2,  2, 19,  19,  0, 34,  1,  0,  0,  1,  0,  0,  4,  0)


###################################################
### code chunk number 41: seqest2
###################################################
seqPar=CDVineSeqEst(dat,family=family,type=1,method="mle")


###################################################
### code chunk number 42: mle
###################################################
mlePar=CDVineMLE(dat,family=family,start=seqPar$par,start2=seqPar$par2,type=1)


###################################################
### code chunk number 43: options_digits1
###################################################
options(digits=6)


###################################################
### code chunk number 44: loglik
###################################################
CDVineLogLik(dat,family=family,par=seqPar$par,par2=seqPar$par2,type=1)$loglik
CDVineLogLik(dat,family=family,par=mlePar$par,par2=mlePar$par2,type=1)$loglik


###################################################
### code chunk number 45: options_digits2
###################################################
options(digits=4)


###################################################
### code chunk number 46: tree (eval = FALSE)
###################################################
## P=CDVineTreePlot(data=NULL,family=family,par=mlePar$par,par2=mlePar$par2,names=colnames(dat),type=1,tree=1,edge.labels=c("family","theotau"))


###################################################
### code chunk number 47: ps.options
###################################################
ps.options(fonts=c("sans"))


###################################################
### code chunk number 48: dvine
###################################################
order_dvine=c(1, 4, 5, 6, 2, 3)
dvine=CDVineCopSelect(worldindices[,order_dvine],type="DVine",indeptest=TRUE)
family_dvine=dvine$family
mle_dvine=CDVineMLE(worldindices[,order_dvine], family_dvine, type="DVine")
par_dvine=mle_dvine$par
par2_dvine=mle_dvine$par2


###################################################
### code chunk number 49: options2
###################################################
options(width = 70)


###################################################
### code chunk number 50: vuong
###################################################
CDVineVuongTest(worldindices, Model1.order=order,Model2.order=order_dvine, Model1.family=family, Model2.family=family_dvine, Model1.par=mlePar$par, Model2.par=par_dvine,Model1.par2=mlePar$par2,Model2.par2=par2_dvine,Model1.type=1, Model2.type=2)


